==> libgphoto2_2.5.27.orig.tar.xz: libgphoto2-2.5.27/camlibs/polaroid/jd350e_blue.h <==
/* jd350e_blue.h
 *
 * White balancing curve for indoor / electric light pictures
 * (experimental)
 *
 * Copyright 2001 Michael Trawny <trawny99@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */
static  unsigned jd350e_blue_curve [] = {
  0, 2, 5, 7,
  10, 13, 15, 18,
  21, 22, 25, 28,
  31, 34, 36, 39,
  41, 45, 47, 51,
  53, 56, 58, 62,
  64, 67, 69, 72,
  74, 77, 79, 81,
  84, 86, 89, 92,
  95, 99, 102, 107,
  110, 113, 116, 119,
  121, 122, 124, 125,
  127, 129, 131, 133,
  136, 139, 141, 144,
  147, 149, 151, 154,
  156, 159, 161, 164,
  166, 168, 170, 173,
  175, 177, 180, 182,
  184, 187, 189, 192,
  194, 196, 198, 201,
  203, 206, 208, 211,
  213, 215, 217, 219,
  220, 220, 220, 220,
  221, 221, 221, 221,
  221, 222, 222, 222,
  222, 223, 223, 223,
  223, 223, 224, 224,
  224, 224, 224, 225,
  225, 225, 225, 225,
  226, 226, 226, 226,
  226, 227, 227, 227,
  227, 227, 228, 228,
  228, 228, 229, 229,
  229, 229, 229, 230,
  230, 230, 230, 230,
  231, 231, 231, 231,
  231, 232, 232, 232,
  232, 232, 233, 233,
  233, 233, 234, 234,
  234, 234, 234, 235,
  235, 235, 235, 235,
  236, 236, 236, 236,
  236, 237, 237, 237,
  237, 237, 238, 238,
  238, 238, 239, 239,
  239, 239, 239, 240,
  240, 240, 240, 240,
  241, 241, 241, 241,
  241, 242, 242, 242,
  242, 242, 243, 243,
  243, 243, 243, 244,
  244, 244, 244, 245,
  245, 245, 245, 245,
  246, 246, 246, 246,
  246, 247, 247, 247,
  247, 247, 248, 248,
  248, 248, 248, 249,
  249, 249, 249, 250,
  250, 250, 250, 250,
  251, 251, 251, 251,
  251, 252, 252, 252,
  252, 252, 253, 253,
  253, 253, 253, 254,
  254, 254, 254, 255};

==> libgphoto2_2.5.33.orig.tar.xz: libgphoto2-2.5.33/camlibs/polaroid/jd350e_blue.h <==
#ifndef CAMLIBS_POLAROID_JD350E_BLUE_H
#define CAMLIBS_POLAROID_JD350E_BLUE_H

/* jd350e_blue.h
 *
 * White balancing curve for indoor / electric light pictures
 * (experimental)
 *
 * Copyright 2001 Michael Trawny <trawny99@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */
static  unsigned jd350e_blue_curve [] = {
  0, 2, 5, 7,
  10, 13, 15, 18,
  21, 22, 25, 28,
  31, 34, 36, 39,
  41, 45, 47, 51,
  53, 56, 58, 62,
  64, 67, 69, 72,
  74, 77, 79, 81,
  84, 86, 89, 92,
  95, 99, 102, 107,
  110, 113, 116, 119,
  121, 122, 124, 125,
  127, 129, 131, 133,
  136, 139, 141, 144,
  147, 149, 151, 154,
  156, 159, 161, 164,
  166, 168, 170, 173,
  175, 177, 180, 182,
  184, 187, 189, 192,
  194, 196, 198, 201,
  203, 206, 208, 211,
  213, 215, 217, 219,
  220, 220, 220, 220,
  221, 221, 221, 221,
  221, 222, 222, 222,
  222, 223, 223, 223,
  223, 223, 224, 224,
  224, 224, 224, 225,
  225, 225, 225, 225,
  226, 226, 226, 226,
  226, 227, 227, 227,
  227, 227, 228, 228,
  228, 228, 229, 229,
  229, 229, 229, 230,
  230, 230, 230, 230,
  231, 231, 231, 231,
  231, 232, 232, 232,
  232, 232, 233, 233,
  233, 233, 234, 234,
  234, 234, 234, 235,
  235, 235, 235, 235,
  236, 236, 236, 236,
  236, 237, 237, 237,
  237, 237, 238, 238,
  238, 238, 239, 239,
  239, 239, 239, 240,
  240, 240, 240, 240,
  241, 241, 241, 241,
  241, 242, 242, 242,
  242, 242, 243, 243,
  243, 243, 243, 244,
  244, 244, 244, 245,
  245, 245, 245, 245,
  246, 246, 246, 246,
  246, 247, 247, 247,
  247, 247, 248, 248,
  248, 248, 248, 249,
  249, 249, 249, 250,
  250, 250, 250, 250,
  251, 251, 251, 251,
  251, 252, 252, 252,
  252, 252, 253, 253,
  253, 253, 253, 254,
  254, 254, 254, 255};

#endif /* !defined(CAMLIBS_POLAROID_JD350E_BLUE_H) */
